@@ -1,4 +1,4 @@
-/* $Id: random.c,v 1.4 2000/09/04 20:46:10 amura Exp $ */
+/* $Id: random.c,v 1.4.2.3 2001/07/23 18:15:56 amura Exp $ */
 /*
  *		Assorted commands.
  * The file contains the command
@@ -9,6 +9,15 @@
 
 /*
  * $Log: random.c,v $
+ * Revision 1.4.2.3  2001/07/23 18:15:56  amura
+ * now buffers have only one mark (before windows have one mark)
+ *
+ * Revision 1.4.2.2  2001/07/23 18:01:30  amura
+ * fix mark handling when make newline on the mark position
+ *
+ * Revision 1.4.2.1  2001/06/19 18:09:38  amura
+ * add correcting mark position when yank empty line
+ *
  * Revision 1.4  2000/09/04 20:46:10  amura
  * fix yank() bug appeared from rev 1.3
  *
@@ -649,6 +658,7 @@ yank(f, n)
 	register LINE	*lp;
 	register int	nline;
 	VOID	 isetmark();
+	int mark_adjust = FALSE;
 #ifdef	UNDO
 	int run_insert = FALSE;
 #endif
@@ -677,10 +687,19 @@ yank(f, n)
 		set_lineno = get_lineno(curbp, curwp->w_dotp);
 		while ((c=kremove(i)) >= 0) {
 			if (c == '\n') {
+				if (i == 0 && curbp->b_marko == 0)
+					mark_adjust = TRUE;
 				if (newline(FFRAND, 1) == FALSE) {
 					set_lineno = -1;
 					return FALSE;
 				}
+				/* Mark position correction.	*/
+				if (mark_adjust) {
+					LINE *lp=lback(curwp->w_dotp);
+					curbp->b_markp  = lp;
+					curbp->b_marko  = llength(lp);
+					mark_adjust = FALSE;
+				}
 				++nline; ++set_lineno;
 				run_insert = FALSE;
 			} else {
@@ -701,8 +720,18 @@ yank(f, n)
 #endif
 		while ((c=kremove(i)) >= 0) {
 			if (c == '\n') {
+				if (i == 0 && curbp->b_marko == 0)
+					mark_adjust = TRUE;
 				if (newline(FFRAND, 1) == FALSE)
 					return FALSE;
+				/* Mark position correction.	*/
+				if (mark_adjust) {
+					LINE *lp=lback(curwp->w_dotp);
+					curbp->b_markp  = lp;
+					curbp->b_marko  = llength(lp);
+					mark_adjust = FALSE;
+				}
+				
 				++nline;
 			} else {
 				if (linsert(1, c) == FALSE)
@@ -906,8 +935,8 @@ regionlines(f, n)
 	register int	counting;
 
 	totallines = 0;
-	if (curwp->w_dotp == curwp->w_markp) {
-		if (curwp->w_doto != curwp->w_marko) {
+	if (curwp->w_dotp == curbp->b_markp) {
+		if (curwp->w_doto != curbp->b_marko) {
 			totallines = 1;
 		}
 	} else {
@@ -923,9 +952,9 @@ regionlines(f, n)
 				} else {	/* Start of counting. */
 					counting = TRUE;
 				}
-			} else if (lp == curwp->w_markp) {
+			} else if (lp == curbp->b_markp) {
 				if (counting) {	/* End of counting. */
-					if (curwp->w_marko > 0) {
+					if (curbp->b_marko > 0) {
 						totallines++;
 					}
 					break;
